use std::collections::HashMap;

use bitfinex::api::Bitfinex;

use crate::pairs::PairStatus;
use crate::ticker::Ticker;
use core::time::Duration;

struct BfxBot {
    bfx: Bitfinex,
    ticker: Ticker,
    pair_status: HashMap<String, PairStatus>,
    quote: String,
    account_info: String,
    ledger: String,
}

impl BfxBot {
    pub fn new<S: Into<String>>(api_key: S, api_secret: S, pairs: Vec<String>, quote: String, tick_duration: Duration) -> Self {
        BfxBot {
            bfx: Bitfinex::new(Some(api_key.into()), Some(api_secret.into())),
            ticker: Ticker::new(tick_duration),
            pair_status: HashMap::new(),
            quote,
            account_info: String::new(),
            ledger: String::new(),
        }
    }
}

